# finsym

__finsym__ is a package that contains code that I found useful for the serialization and deserialization of Financial Symbols and represents an abstraction of the mapping of an ticker (unique identifier) to its symbology (the provider/vendor). The motivation for this package was to provide a basic abstraction for some symbol translation work that I needed to do.
